﻿// ParamComparer.cs

using System;
using System.Reflection;
using N14PKBrowse.Data;

using N14PKBrowse.Sort;

namespace N14PKBrowse.Compare
{
	// 比較オブジェクト Param
	public class ParamComparer : AbstractComparer
	{
		/// <summary>比較用コールバックデリゲート Param</summary>
		private delegate int SubCallback( Param x, Param y, bool isAsc );

		/// <summary>比較用コールバックデリゲート Param</summary>
		private SubCallback _subCallback;


		/// <summary>コールバックデリゲートを取得する</summary>
		/// <param name="propertyName">プロパティ名</param>
		/// <returns>コールバックデリゲート</returns>
		public override CompareCallback GetCallback( string propertyName )
		{
			var type = this.GetType();
			// メソッド情報取得
			var mi = type.GetMethod( _CallbackPrefix + propertyName, BindingFlags.NonPublic | BindingFlags.Instance );
			if ( mi == null )
			{
				return null;
			}
			// デリゲート作成
			this._subCallback = (SubCallback)Delegate.CreateDelegate( typeof( SubCallback ), this, mi );
			this._callback = this.CompareCallback;
			return ( this._subCallback != null ) ? this._callback : null;
		}

		/// <summary>コールバックデリゲートを設定する(ICompare を使用するカスタムソート用)</summary>
		/// <param name="propertyName">プロパティ名</param>
		/// <param name="isAsc">ソートオーダー</param>
		/// <returns>デリゲートが取得できたら true を返す</returns>
		public override bool SetCallback( string propertyName, bool isAsc )
		{
			this._isAsc = isAsc;
			this._callback = this.GetCallback( propertyName );
			return ( this._callback != null ) ? true : false;
		}

		/// <summary>ソート時に使用するコールバック</summary>
		private int CompareCallback( object x, object y, bool isAsc )
		{
			return this._subCallback( x as Param, y as Param, isAsc );
		}

		#region コールバックメソッド
		private int CmpDefaultValue( Param x, Param y, bool isAsc )
		{
			return x.Data.DefaultValue.Equals( y.Data.DefaultValue ) ? 0
				: ( x.Data.DefaultValue == null ) ? isAsc ? 1 : -1
				: ( y.Data.DefaultValue == null ) ? isAsc ? -1 : 1
				: (int)( x.Data.DefaultValue - y.Data.DefaultValue );
		}
		#endregion
	}
}
