﻿// YousyoComparer.cs

using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Text;
using N14PKBrowse.Data;

namespace N14PKBrowse.Compare
{
	// 比較オブジェクト 要所
	public class YousyoComparer : AbstractComparer
	{
		/// <summary>比較用コールバックデリゲート 要所</summary>
		private delegate int SubCallback( Yousyo x, Yousyo y, bool isAsc );

		/// <summary>比較用コールバックデリゲート 要所</summary>
		private SubCallback _subCallback;


		/// <summary>コールバックデリゲートを取得する</summary>
		/// <param name="propertyName">プロパティ名</param>
		/// <returns>コールバックデリゲート</returns>
		public override CompareCallback GetCallback( string propertyName )
		{
			var type = this.GetType();
			// メソッド情報取得
			var mi = type.GetMethod( _CallbackPrefix + propertyName, BindingFlags.NonPublic | BindingFlags.Instance );
			if ( mi == null )
			{
				return null;
			}
			// デリゲート作成
			this._subCallback = (SubCallback)Delegate.CreateDelegate( typeof( SubCallback ), this, mi );
			this._callback = this.CompareCallback;
			return ( this._subCallback != null ) ? this._callback : null;
		}

		/// <summary>コールバックデリゲートを設定する(ICompare を使用するカスタムソート用)</summary>
		/// <param name="propertyName">プロパティ名</param>
		/// <param name="isAsc">ソートオーダー</param>
		/// <returns>デリゲートが取得できたら true を返す</returns>
		public override bool SetCallback( string propertyName, bool isAsc )
		{
			this._isAsc = isAsc;
			this._callback = this.GetCallback( propertyName );
			return ( this._callback != null ) ? true : false;
		}

		/// <summary>ソート時に使用するコールバック</summary>
		private int CompareCallback( object x, object y, bool isAsc )
		{
			return this._subCallback( x as Yousyo, y as Yousyo, isAsc );
		}

		#region コールバックメソッド
		private int CmpName( Yousyo x, Yousyo y, bool isAsc )			// 要所名
		{
			return x.Yomi.Equals( y.Yomi ) ? 0
				: ( x.Yomi == string.Empty ) ? isAsc ? 1 : -1
				: ( y.Yomi == string.Empty ) ? isAsc ? -1 : 1
				: x.Yomi.CompareTo( y.Yomi );
		}

		private int CmpChihou( Yousyo x, Yousyo y, bool isAsc )			// 地方
		{
			return (int)( x.N14pkb.Kunilist[x.Data.PtrKuni].Data.PtrChihou - y.N14pkb.Kunilist[y.Data.PtrKuni].Data.PtrChihou );
		}

		private int CmpKuni( Yousyo x, Yousyo y, bool isAsc )			// 国
		{
			return (int)( x.Data.PtrKuni - y.Data.PtrKuni );
		}

		private int CmpKyoten( Yousyo x, Yousyo y, bool isAsc )		// 拠点
		{
			var x_id = x.N14pkb.Yousyolist.GetSortIDByKyotenAddress( x.Data.PtrKyoten );
			var y_id = y.N14pkb.Yousyolist.GetSortIDByKyotenAddress( y.Data.PtrKyoten );
			return ( x_id == y_id ) ? 0
				: ( x_id == -1 ) ? isAsc ? 1 : -1
				: ( y_id == -1 ) ? isAsc ? -1 : 1
				: x_id - y_id;
		}

		private int CmpKyotenSeiryoku( Yousyo x, Yousyo y, bool isAsc )		// 勢力
		{
			var x_id = x.N14pkb.Seiryokulist.GetSortIDByAddress( x.PtrSeiryoku );
			var y_id = y.N14pkb.Seiryokulist.GetSortIDByAddress( y.PtrSeiryoku );
			return ( x_id == y_id ) ? 0
				: ( x_id == -1 ) ? isAsc ? 1 : -1
				: ( y_id == -1 ) ? isAsc ? -1 : 1
				: x_id - y_id;
		}

		private int CmpPtrJinSetsueiSeiryoku( Yousyo x, Yousyo y, bool isAsc )		// 陣設営勢力
		{
			var x_id = x.N14pkb.Seiryokulist.GetSortIDByAddress( x.PtrJinSetsueiSeiryoku );
			var y_id = y.N14pkb.Seiryokulist.GetSortIDByAddress( y.PtrJinSetsueiSeiryoku );
			return ( x_id == y_id ) ? 0
				: ( x_id == -1 ) ? isAsc ? 1 : -1
				: ( y_id == -1 ) ? isAsc ? -1 : 1
				: x_id - y_id;
		}
		#endregion
	}
}
