﻿using System;

namespace N14PKLibrary.VersionConfig
{
	/// <summary>バージョン 1.0.5.0 用設定情報</summary>
	public class V1050 : IVersionConfig
	{
		/// <summary>プロセス名</summary>
		public String ProcessName { get { return "NOBU14PK"; } }

		/// <summary>NOBU14PK.EXE のCRC32</summary>
		public UInt32 Nobu14pkCrc32 { get { return 0; } }

		/// <summary>steam_api.dll のCRC32</summary>
		public UInt32 Steam_apiCrc32 { get { return 0; } }

		/// <summary>各データテーブルの構造情報が格納されているインデクステーブルへのポインタアドレス
		/// <para>(ベースアドレスからのオフセット)</para></summary>
		public UInt32 IndexTblPointerAddress { get { return 0x04163B80; } }

		/// <summary>インデクステーブルのレコードサイズ</summary>
		public UInt32 IndexTblRecordSize { get { return 0x10; } }

		/// <summary>インデクステーブルのレコード数</summary>
		public UInt32 IndexTblRecordCount { get { return 0x22; } }

		/// <summary>インデクステーブルアドレスから実際のインデクス情報の先頭レコードまでのオフセット</summary>
		public UInt32 OffsetIndexTblAddress { get { return 0xB0; } }

		/// <summary>インデクステーブルアドレスからシナリオ名へのポインタアドレスまでのオフセット</summary>
		public UInt32 OffsetScenarioNamePointerAddress { get { return 0x2D4; } }

		/// <summary>シナリオ名アドレスからゲーム内日時データアドレスまでのオフセット</summary>
		public UInt32 OffsetDateTime { get { return 0x1CC; } }

		/// <summary>武将データ数</summary>
		/// <remarks>IndexTblPointerAddress で直接インデクステーブルを取得した場合の確認用に使用する</remarks>
		public UInt32 BusyouDataCount { get { return 0xE26; } }

		/// <summary>武将データレコードサイズ</summary>
		/// <remarks>蠣崎サーチ時に武将データ内の名前でヒットしたかどうかを判断するのに使用する</remarks>
		public UInt32 BusyouDataRecoedSize { get { return 0x170; } }

		/// <summary>Paramデータインデクスの先頭アドレス
		/// <para>(ベースアドレスからのオフセット)</para></summary>
		public UInt32 ParamIndexAddress { get { return 0x0078685E; } }

		/// <summary>Paramデータ初期値配列</summary>
		public Int32[] ParamDefaultValues { get { return V1050.PARAM_DEFAULT_VALUE; } }

		///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
		/// <summary>Paramデータ初期値配列</summary>
		public static readonly Int32[] PARAM_DEFAULT_VALUE =
		{
			#region Param初期値 データ数1764
			1024,
			1,
			120,
			30,
			30,
			35,
			125,
			125,
			125,
			7500,
			1,
			24,
			240,
			150,
			150,
			150,
			65,
			180,
			4,
			100,
			100,
			200,
			300,
			500,
			3000,
			6000,
			8000,
			20000,
			1,
			70,
			100000,
			40,
			50,
			50,
			6,
			70,
			1,
			10,
			200000,
			10,
			25,
			1000,
			4,
			6,
			12,
			3,
			7,
			3,
			5,
			1,
			1,
			10,
			10,
			20,
			40,
			50,
			200,
			100,
			80,
			60,
			10,
			50,
			5,
			5,
			5,
			1,
			150,
			100,
			10,
			30,
			50000,
			1000,
			20,
			5,
			2000,
			4000,
			8000,
			6000,
			9000,
			12000,
			10,
			110,
			400,
			500,
			150,
			500,
			400,
			1000,
			500,
			2,
			6,
			5,
			8,
			60,
			6,
			6,
			12,
			2,
			4,
			3000,
			100,
			2,
			200,
			30,
			30,
			50,
			30,
			30,
			20,
			7,
			5000,
			70,
			2,
			10,
			3,
			10,
			50,
			40,
			60,
			80,
			90,
			50,
			100,
			50,
			0,
			-50,
			-75,
			77,
			66,
			80,
			7,
			5,
			18,
			24,
			15,
			36,
			26,
			50,
			16,
			24,
			20,
			24,
			48,
			14,
			6,
			30,
			6,
			10,
			2,
			9,
			12,
			10,
			10,
			10,
			10,
			10,
			2,
			10,
			10,
			1,
			50,
			3,
			90,
			15,
			30,
			30,
			50,
			5,
			200,
			50,
			50,
			500,
			500,
			15,
			150,
			2000,
			5,
			15,
			16,
			12,
			2,
			20,
			20,
			20,
			25,
			500,
			400,
			300,
			200,
			100,
			30,
			20,
			15,
			10,
			-120,
			20,
			15,
			10,
			5,
			0,
			20,
			15,
			10,
			5,
			0,
			30,
			60,
			30,
			50,
			20,
			4,
			2,
			200,
			1,
			3500,
			60,
			2,
			170,
			200,
			60,
			70,
			70,
			20,
			120,
			200,
			60,
			70,
			70,
			1000,
			30,
			4000,
			500,
			60,
			800,
			30,
			4000,
			10,
			20,
			20,
			2,
			15,
			30,
			6,
			7,
			3000,
			2500,
			30,
			12,
			30,
			12,
			12,
			15,
			3000,
			100,
			3,
			1000,
			20,
			20,
			20,
			10,
			10,
			8,
			50,
			2,
			20,
			50,
			6,
			6,
			30,
			30,
			30,
			7,
			20,
			500,
			5,
			3,
			6,
			30,
			6,
			2000,
			15000,
			20,
			120,
			3,
			150,
			180,
			3000,
			2000,
			5,
			100,
			100,
			100,
			60,
			2000,
			5000,
			15,
			40,
			400,
			20000,
			30000,
			3,
			2000,
			5,
			6000,
			6000,
			1000,
			10000,
			13000,
			5000,
			13000,
			15000,
			10000,
			10000,
			10000,
			1000,
			1000,
			5,
			20000,
			10000,
			3000,
			1000,
			3000,
			270,
			5000,
			5000,
			750,
			1500,
			180,
			10000,
			75,
			300,
			1200,
			3000,
			1000,
			50,
			5,
			1000,
			500,
			1,
			10000,
			8000,
			200,
			100,
			50000,
			80,
			80,
			80,
			80,
			70,
			80,
			80,
			70,
			0,
			0,
			0,
			0,
			100,
			500,
			10,
			5,
			2500,
			5000,
			20000,
			10000,
			2000,
			5000,
			80,
			400,
			200,
			150,
			2000,
			5,
			5,
			20000,
			20000,
			150,
			5,
			50000,
			60,
			150,
			120,
			150,
			50,
			80,
			80,
			50,
			15,
			0,
			0,
			15,
			10000,
			10000,
			2,
			3,
			1,
			2,
			3000,
			10000,
			200,
			50,
			51,
			21,
			64,
			65,
			30,
			956,
			965,
			338,
			1,
			1,
			5000,
			1,
			6,
			100,
			0,
			0,
			50,
			40,
			1000,
			1500,
			2000,
			2500,
			800,
			1000,
			70,
			10,
			10,
			130,
			100,
			40,
			20,
			10000,
			15000,
			20000,
			25000,
			20,
			2,
			100,
			360,
			500,
			5000,
			10,
			70,
			15,
			6,
			6,
			20,
			5,
			5,
			60,
			90,
			130,
			4,
			12,
			12,
			12,
			50,
			50,
			50,
			400,
			3,
			40,
			5,
			5,
			2000,
			10,
			50,
			200,
			50,
			30000,
			50,
			120,
			20,
			20,
			1,
			1,
			100,
			30000,
			50,
			465,
			291,
			291,
			320,
			320,
			70000,
			70000,
			70000,
			70000,
			50000,
			50000,
			50000,
			50000,
			1,
			1,
			300,
			40,
			1000,
			50,
			20,
			1200,
			1200,
			600,
			600,
			5,
			70,
			600,
			2,
			2,
			100,
			100,
			0,
			5,
			10,
			300,
			1,
			15,
			10,
			5,
			20,
			9999,
			2,
			30,
			30,
			3,
			10,
			50,
			80,
			300,
			100,
			200,
			1000,
			3000,
			40,
			60,
			70,
			80,
			100,
			80,
			20,
			30,
			40,
			6,
			6,
			6,
			6,
			6,
			6,
			20,
			20,
			20,
			20,
			20,
			20,
			500,
			1000,
			1500,
			2000,
			90,
			600,
			50,
			100,
			80,
			2000,
			10,
			10,
			10,
			20,
			60000,
			20,
			10,
			25,
			10,
			900,
			300,
			400,
			300,
			40,
			40,
			20,
			3,
			12,
			20,
			600,
			50,
			600,
			50,
			50,
			0,
			71,
			1200,
			50,
			-1000,
			80,
			1200,
			50,
			50,
			-1000,
			40,
			600,
			50,
			0,
			71,
			600,
			50,
			9999,
			0,
			0,
			70,
			70,
			0,
			70,
			70,
			30,
			30,
			30,
			30,
			30,
			30,
			-10,
			70,
			10,
			70,
			-10,
			70,
			10,
			70,
			-10,
			70,
			10,
			70,
			-10,
			70,
			10,
			70,
			-1,
			70,
			20,
			70,
			-10,
			70,
			10,
			70,
			100,
			100,
			100,
			100,
			100,
			100,
			4,
			3,
			3,
			3,
			3,
			3,
			2,
			0,
			3,
			0,
			0,
			0,
			20,
			10,
			25,
			10,
			20,
			4999,
			30,
			30,
			30,
			30,
			30,
			51,
			30,
			30,
			30,
			30,
			30,
			30,
			51,
			30,
			51,
			51,
			51,
			51,
			51,
			51,
			500,
			4,
			4000,
			5,
			1,
			15000,
			25000,
			30000,
			100,
			90,
			80,
			70,
			60,
			1,
			2,
			1,
			4,
			1,
			2,
			8,
			3,
			9,
			10,
			2,
			4000,
			4,
			80000,
			200000,
			-40,
			-70,
			-100,
			90000,
			180,
			60,
			1400,
			6,
			8,
			1,
			20000,
			60000,
			100000,
			4999,
			3,
			5000,
			5,
			100,
			70,
			80,
			120,
			60,
			110,
			110,
			90,
			180,
			40,
			20,
			60,
			70,
			6,
			9,
			100,
			900,
			60,
			360,
			6000,
			2000,
			30000,
			100,
			60,
			80,
			60,
			20,
			15,
			30,
			40,
			40,
			30,
			30,
			20,
			4,
			2,
			100,
			500,
			50,
			6,
			40,
			1000,
			60,
			70,
			70,
			60,
			800,
			300,
			25,
			2500,
			500,
			3,
			50,
			1,
			1000,
			100,
			150,
			75,
			10,
			30,
			1000,
			4,
			4,
			3,
			50,
			3,
			1,
			1,
			5,
			500,
			50,
			5000,
			130,
			200,
			80,
			1,
			2,
			90,
			180,
			3,
			90,
			90,
			720,
			60,
			70,
			10,
			40,
			20,
			1500,
			60,
			3000,
			200,
			65,
			10,
			50,
			100000,
			8,
			5,
			97,
			10,
			15,
			150,
			50,
			30,
			1000,
			10,
			5,
			3,
			2,
			2,
			120,
			2000,
			35,
			60,
			10,
			5,
			7,
			10,
			15,
			10,
			15,
			20,
			30,
			10,
			20,
			30,
			40,
			5,
			5,
			10,
			10,
			5,
			10,
			90,
			5,
			20,
			10,
			60,
			3,
			1000,
			20,
			10,
			10,
			10,
			5,
			5,
			10,
			60,
			3,
			125,
			150,
			25,
			25,
			60,
			5,
			3,
			3,
			600,
			30000,
			300,
			300,
			175,
			0,
			100,
			50,
			24,
			50,
			50,
			2,
			3,
			6,
			2000,
			40,
			1000,
			5000,
			300000,
			20,
			40,
			50,
			60,
			170,
			180,
			190,
			90,
			5,
			20,
			500,
			100,
			120,
			60,
			4,
			75,
			2,
			1000,
			90,
			1,
			35,
			1600,
			3,
			6,
			10,
			20,
			6,
			30,
			75,
			12,
			10,
			30,
			3000,
			5000,
			7000,
			9000,
			1000,
			2000,
			3000,
			4000,
			4000,
			6000,
			8000,
			9000,
			2000,
			3000,
			4000,
			5000,
			20000,
			25000,
			30000,
			35000,
			40000,
			45000,
			50000,
			30,
			50,
			150,
			500,
			2,
			10,
			3,
			30,
			110,
			3000,
			30,
			3000,
			500,
			100,
			8000,
			300,
			300,
			40,
			5000,
			5,
			0,
			-1,
			-2,
			4,
			0,
			0,
			-3,
			3,
			10,
			3,
			4,
			10,
			50,
			100,
			200,
			45,
			55,
			-1,
			4,
			0,
			1000,
			5,
			1000,
			900,
			700,
			500,
			250,
			100,
			0,
			-2,
			0,
			2,
			-2,
			0,
			2,
			5,
			2,
			7,
			1,
			1,
			3,
			5,
			8,
			15,
			20,
			5,
			7,
			10,
			20,
			5,
			100,
			90,
			80,
			60,
			50,
			70,
			12000,
			1000,
			50,
			2000,
			1000,
			10,
			10,
			10,
			20,
			45,
			60,
			50,
			50,
			50,
			50,
			60,
			50,
			55,
			70,
			65,
			50,
			55,
			65,
			55,
			55,
			50,
			70,
			65,
			55,
			50,
			45,
			65,
			50,
			55,
			65,
			70,
			50,
			65,
			60,
			55,
			70,
			60,
			50,
			45,
			60,
			50,
			55,
			55,
			40,
			55,
			50,
			40,
			40,
			65,
			45,
			60,
			50,
			70,
			50,
			50,
			55,
			60,
			65,
			65,
			60,
			60,
			55,
			50,
			70,
			45,
			50,
			55,
			50,
			65,
			50,
			45,
			60,
			50,
			45,
			55,
			50,
			60,
			65,
			60,
			50,
			3000,
			30,
			1000,
			50,
			120,
			5000,
			200,
			300,
			5000,
			300,
			15,
			500,
			20,
			15,
			500,
			20,
			2,
			2,
			2,
			5000,
			50,
			700,
			300,
			100,
			50,
			90,
			70,
			50,
			3,
			2,
			100,
			100,
			100,
			100,
			100,
			100,
			5,
			30,
			5,
			5,
			800,
			600,
			400,
			3200,
			2000,
			1400,
			3000,
			6600,
			3000,
			2800,
			2200,
			8200,
			200,
			300,
			400,
			100,
			200,
			300,
			340,
			100,
			160,
			260,
			360,
			100,
			10,
			-10,
			-30,
			30,
			-150,
			-300,
			-200,
			-400,
			-400,
			70,
			0,
			20,
			60,
			100,
			15,
			30,
			25,
			20,
			8000,
			100,
			400,
			60,
			60,
			9999,
			9999,
			9999,
			9999,
			9999,
			2,
			2,
			2,
			0,
			0,
			4,
			3,
			4,
			0,
			0,
			12,
			12,
			8,
			8,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			0,
			20,
			5,
			1,
			0,
			35,
			60,
			85,
			20,
			100,
			100,
			70,
			2,
			15,
			15,
			15,
			7,
			7,
			7,
			20,
			11,
			36,
			20,
			100,
			2000,
			10000,
			100,
			60,
			50,
			40,
			10,
			8,
			4,
			10,
			50,
			10,
			10,
			10,
			25,
			10,
			10,
			10,
			200,
			100,
			1,
			100,
			75,
			50,
			25,
			100,
			100,
			150,
			150,
			150,
			3000,
			2000,
			40000,
			200,
			10,
			150,
			5,
			200,
			100,
			300,
			500,
			12,
			8,
			2,
			40,
			1000,
			2000,
			1000,
			24,
			30,
			30,
			30,
			60,
			4,
			500,
			200,
			300,
			30,
			30,
			30,
			8,
			4,
			192,
			150,
			300,
			4,
			24,
			800,
			30,
			30,
			20,
			20,
			20,
			20,
			1,
			50,
			5000,
			10,
			10,
			30,
			100,
			800,
			800,
			2,
			7,
			200,
			3000,
			1000,
			3000,
			1000,
			20000,
			10000,
			10000,
			10000,
			5000,
			30,
			3,
			3,
			100,
			20000,
			10000,
			5,
			80,
			50000,
			30000,
			30000,
			30,
			300,
			2000,
			3,
			3,
			7,
			30,
			40,
			45,
			8,
			1420,
			20,
			2,
			-3,
			0,
			-2,
			-1,
			0,
			-3,
			3,
			1000,
			300,
			1000,
			4,
			0,
			1,
			3,
			2,
			6,
			10,
			5,
			5,
			-64,
			-34,
			850,
			850,
			10,
			400,
			10,
			100,
			100,
			3072,
			10,
			600,
			500,
			400,
			140,
			150,
			120,
			150,
			100,
			5,
			1700,
			10,
			25000,
			10000,
			20,
			30,
			200,
			5,
			12,
			4,
			4,
			1543,
			8,
			2,
			3,
			50,
			60,
			25,
			2,
			3,
			60,
			60,
			25,
			100,
			5,
			-1,
			5,
			8,
			12,
			20,
			30,
			60,
			100,
			-1,
			-3,
			60,
			70,
			60,
			70,
			60,
			70,
			60,
			70,
			6,
			1529,
			700,
			2800,
			500,
			2600,
			300,
			2400,
			100,
			2200,
			3,
			1,
			3,
			1,
			5,
			10,
			29,
			35,
			34,
			37,
			27,
			31,
			1,
			0,
			600,
			1200,
			2000,
			300,
			40,
			80,
			100,
			3,
			3,
			5,
			90,
			30,
			60,
			50,
			10,
			20,
			1,
			10,
			60,
			30,
			0,
			0,
			30,
			5,
			260,
			70,
			3,
			30,
			3,
			40,
			12,
			5,
			33,
			30,
			0,
			0,
			0,
			300,
			50000,
			6,
			100,
			120,
			140,
			200,
			120,
			140,
			160,
			200,
			70,
			90,
			110,
			130,
			90,
			110,
			130,
			150,
			0,
			10,
			20,
			30,
			5000,
			4,
			4,
			4,
			12,
			50,
			1000,
			3000,
			5000,
			50,
			100,
			5,
			360,
			2000,
			200,
			5,
			20,
			15,
			20,
			33,
			7000,
			5000,
			2000,
			1500,
			1000,
			3000,
			5000,
			7000,
			2000,
			4000,
			1500,
			4,
			120,
			200,
			40,
			60,
			80,
			100,
			3000,
			1000,
			10,
			10,
			36,
			20,
			60,
			100,
			25,
			200,
			3000,
			5,
			5,
			5,
			6,
			6,
			7,
			7,
			8,
			8,
			8,
			8,
			9,
			9,
			9,
			9,
			10,
			10,
			100,
			100,
			4000,
			5,
			5,
			80,
			150,
			100,
			1,
			10,
			60,
			60,
			60,
			40,
			20,
			20,
			20,
			0,
			100,
			36,
			15000,
			4100,
			6,
			6,
			20,
			20,
			5,
			5,
			5,
			5,
			5,
			5,
			5,
			5,
			30,
			90,
			40000,
			150,
			50,
			20,
			0,
			20,
			3,
			1000,
			20,
			2,
			2,
			12,
			20,
			4500,
			18,
			8,
			100,
			3,
			0,
			1200,
			71,
			50,
			70,
			30,
			-10,
			10,
			70,
			70,
			30,
			30,
			51,
			100,
			600,
			50,
			70,
			30,
			-10,
			10,
			70,
			70,
			30,
			30,
			51,
			100,
			10,
			20,
			30,
			40,
			10,
			20,
			30,
			40,
			1000,
			20,
			75,
			20,
			80,
			40,
			-2,
			180,
			15,
			200,
			2,
			3,
			70,
			40,
			30,
			20,
			0,
			1,
			0,
			0,
			5,
			70,
			100,
			150,
			100,
			6,
			15,
			1,
			5,
			2,
			1,
			4,
			4,
			4,
			3,
			3,
			90,
			120,
			70,
			130,
			70,
			130,
			70,
			130,
			70,
			130,
			70,
			130,
			70,
			130,
			5000,
			60,
			8000,
			2000,
			1000
			#endregion
		};
	}
}
